﻿using Sandbox;
using System;
using System.Linq;

partial class CPlayer : Player
{
	[Net] public PawnController VehicleController { get; set; }
	[Net] public PawnAnimator VehicleAnimator { get; set; }
	[Net] public CarEntity Vehicle { get; set; }
	[Net] public int Score { get; set; }
	[Net, Predicted] public ICamera MainCamera { get; set; }

	public Clothing.Container Clothing = new();
	public CPlayer(Client cl)
	{
		Clothing.LoadFromClient( cl );
	}

	public CPlayer() { }

	public override void Respawn()
	{
		if (IsServer) {
			Health = 100;
			if (Vehicle != null)
			{
				Vehicle.Delete();
				Vehicle = null;
			}
		}
		SetModel( "models/citizen/citizen.vmdl" );
		SetupPhysicsFromModel( PhysicsMotionType.Dynamic, false );
		Clothing.DressEntity( this );

		Controller = new CarController();
		Animator = new CarAnimator();
		Camera = new CarCamera();

		EnableAllCollisions = true;
		EnableDrawing = true;
		EnableHideInFirstPerson = true;
		EnableShadowInFirstPerson = true;

		base.Respawn();
		if (IsServer) {
			Vehicle = new CarEntity();
			Vehicle.Transform = Transform;
			VehicleController = new CarController();
			VehicleAnimator = new CarAnimator();
			Parent = Vehicle;
			LocalPosition = Vector3.Up * 10;
			LocalRotation = Rotation.Identity;
			LocalScale = 1;
			PhysicsBody.Enabled = false;
			Vehicle.driver = this;
		}
	}

	public override void Simulate( Client cl )
	{
		base.Simulate( cl );

		if ( Input.ActiveChild != null )
		{
			ActiveChild = Input.ActiveChild;
		}

		if ( LifeState != LifeState.Alive )
			return;


		//TickPlayerUse();
		SimulateActiveChild( cl, ActiveChild );

		if (Game.Instance.GameRound.gameState != carderby.GameState.START)
		{
			if ( Controller == null )
				Controller = new CarController();
		}
		else
		{
			if ( Controller != null )
				Controller = null;
		}

	}

	public override void OnKilled()
	{
		Health = 0;
		base.OnKilled();

		if ( Vehicle != null )
		{
			Vehicle.Delete();
			Vehicle = null;
		}

		VehicleController = null;
		VehicleAnimator = null;
		Vehicle = null;
		Animator = new StandardPlayerAnimator();
		Camera = null;
		Controller = null;

		EnableAllCollisions = false;
		EnableDrawing = false;

		if (IsServer && Game.Instance.GameRound.gameState == carderby.GameState.PROCESS)
		{
			foreach (Client client in Client.All)
			{
				CPlayer pawn = (CPlayer)client.Pawn;
				if (pawn.Health > 0)
				{
					if ( pawn.NetworkIdent != this.NetworkIdent )
						pawn.Score++;
				}
			}
		}

	}
}



